<?php

namespace App\Http\Controllers\Client;

use App\Http\Controllers\Controller;
use App\Http\Requests\ConnectRequest;
use App\Models\User;
use Illuminate\Support\Facades\Auth;

class ConnectController extends Controller
{
    /**
     *  @OA\Post(
     *    tags={"Clients:Server"},
     *    path="/server/{id}/connect",
     *    summary="Connect to a server",
     *    @OA\Parameter(
     *      name="id",
     *      in="path",
     *      required=true,
     *      @OA\Schema(type="integer")
     *    ),
     *    @OA\RequestBody(
     *      ref="#/components/requestBodies/Connect"
     *    ),
     *    @OA\Response(
     *      response="401",
     *      ref="#/components/responses/401"
     *    ),
     *    @OA\Response(
     *      response="403",
     *      description="Forbidden",
     *      @OA\JsonContent(
     *        @OA\Property(
     *          property="message",
     *          type="string",
     *        ),
     *      )
     *    ),
     *    @OA\Response(
     *      response="422",
     *      ref="#/components/responses/422"
     *    ),
     *    @OA\Response(
     *      response="204",
     *      description="OK"
     *    ),
     *    security={{"jwt":{}}},
     *  )
     */
    public function connect(ConnectRequest $request, $id) {
        $user = User::findOrFail(Auth::guard('client')->id());

        if ($user->server_state == 'connected') {
            return response()->json([
                'message' => 'Client is already connected',
            ], 403);
        }

        $user->server_state = 'connecting';
        $user->server_token = $request->input('token');
        $user->server_id = $id;
        $user->save();
        return response()->noContent();
    }
}
