<?php

namespace App\Http\Controllers\Shared;

use App\Http\Controllers\Controller;
use App\Models\User;
use Illuminate\Http\Request;

class UserController extends Controller
{
    /**
     *  @OA\Get(
     *    tags={"Clients:User"},
     *    path="/user",
     *    summary="Get user list",
     *    @OA\Response(
     *      response="401",
     *      ref="#/components/responses/401"
     *    ),
     *    @OA\Response(
     *      response="200",
     *      description="OK",
     *      @OA\JsonContent(
     *        @OA\Property(
     *          property="users",
     *          type="array",
     *          @OA\Items(ref="#/components/schemas/User")
     *        ),
     *      ),
     *    ),
     *    security={{"jwt":{}}},
     *  )
     */
    public function index()
    {
        return response()->json([
            "users" => User::all()
        ]);
    }

    /**
     *  @OA\Get(
     *    tags={"Clients:User", "Servers:User"},
     *    path="/user/{id}",
     *    summary="Get an user",
     *    @OA\Parameter(
     *      name="id",
     *      in="path",
     *      required=true,
     *      @OA\Schema(type="integer")
     *    ),
     *    @OA\Response(
     *      response="401",
     *      ref="#/components/responses/401"
     *    ),
     *    @OA\Response(
     *      response="404",
     *      ref="#/components/responses/404"
     *    ),
     *    @OA\Response(
     *      response="200",
     *      description="OK",
     *      @OA\JsonContent(
     *        @OA\Property(
     *          property="user",
     *          allOf={
     *            @OA\Schema(ref="#/components/schemas/User"),
     *            @OA\Schema(
     *              @OA\Property(
     *                property="server",
     *                allOf={
     *                  @OA\Schema(ref="#/components/schemas/Server"),
     *                  @OA\Schema(nullable=true)
     *                }
     *              )
     *            )
     *          }
     *        ),
     *      ),
     *    ),
     *    security={{"jwt":{}, "server-jwt": {}}},
     *  )
     */
    public function show($id)
    {
        return response()->json([
            "user" => User::findOrFail($id)->load("server")
        ]);
    }

        /**
     *  @OA\Get(
     *    tags={"Clients:User"},
     *    path="/user/{id}/game",
     *    summary="Get games played by a user",
     *    @OA\Parameter(
     *      name="id",
     *      in="path",
     *      required=true,
     *      @OA\Schema(type="integer")
     *    ),
     *    @OA\Response(
     *      response="401",
     *      ref="#/components/responses/401"
     *    ),
     *    @OA\Response(
     *      response="404",
     *      ref="#/components/responses/404"
     *    ),
     *    @OA\Response(
     *      response="200",
     *      description="OK",
     *      @OA\JsonContent(
     *         allOf={
     *           @OA\Schema(
     *             @OA\Property(
     *               property="games",
     *               allOf={
     *                 @OA\Schema(ref="#/components/schemas/Game"),
     *                 @OA\Schema(nullable=true)
     *               }
     *             )
     *           )
     *         }
     *      ),
     *    ),
     *    security={{"jwt":{}}},
     *  )
     */
    public function index_usergame($id)
    {
        return response()->json([
            "games" => User::findOrFail($id)->games
        ]);
    }

    /**
     *  @OA\Get(
     *    tags={"Clients:User"},
     *    path="/user/{id}/game/{game_id}",
     *    summary="Get a game played by a user",
     *    @OA\Parameter(
     *      name="id",
     *      in="path",
     *      required=true,
     *      @OA\Schema(type="integer")
     *    ),
     *    @OA\Parameter(
     *      name="game_id",
     *      in="path",
     *      required=true,
     *      @OA\Schema(type="integer")
     *    ),
     *    @OA\Response(
     *      response="401",
     *      ref="#/components/responses/401"
     *    ),
     *    @OA\Response(
     *      response="404",
     *      ref="#/components/responses/404"
     *    ),
     *    @OA\Response(
     *      response="200",
     *      description="OK",
     *      @OA\JsonContent(
     *         allOf={
     *           @OA\Schema(
     *             @OA\Property(
     *               property="gamee",
     *               allOf={
     *                 @OA\Schema(ref="#/components/schemas/Game"),
     *               }
     *             )
     *           )
     *         }
     *      ),
     *    ),
     *    security={{"jwt":{}}},
     *  )
     */
    public function show_usergame($id , $game_id)
    {
        return response()->json([
            "game" => User::findOrFail($id)->games()->findOrFail($game_id)
        ]);
    }
}
