<?php

namespace App\Http\Requests;

use Illuminate\Foundation\Http\FormRequest;

/**
 * @OA\RequestBody(
 *   request="Register",
 *   required=true,
 *   @OA\JsonContent(
 *     required={"username", "email","password", "password_confirmation"},
 *     @OA\Property(
 *       property="username",
 *       type="string",
 *       description="Username of the user",
 *     ),
 *     @OA\Property(
 *       property="email",
 *       type="string",
 *       format="email",
 *       description="Email of the user",
 *     ),
 *     @OA\Property(
 *       property="password",
 *       type="string",
 *       description="Password of the user",
 *     ),
 *   ),
 * ),
 */
class RegisterRequest extends FormRequest
{
    /**
     * Determine if the user is authorized to make this request.
     *
     * @return bool
     */
    public function authorize()
    {
        return true;
    }

    /**
     * Get the validation rules that apply to the request.
     *
     * @return array<string, mixed>
     */
    public function rules()
    {
        return [
            'username' => 'required|string|max:255|unique:users',
            'email' => 'required|string|email|max:255|unique:users',
            'password' => 'required|string|min:6',
        ];
    }
}
